<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Subscription;
use App\User;
use Illuminate\Http\Request;

class MandobController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::where('type', 'driver')->latest()->get();
        return view('admin.mandob.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.mandob.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|unique:users,mobile',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active',

        ]);
        $user = new User();
        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->mobile = $request['mobile'];
        $user->type = 'driver';
        $user->status = $request['status'];
        $user->password = bcrypt($request['password']);
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        $user->save();
        $rand = rand('111', '999');
        $user->personal_code = $user->id . $rand;
        $user->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('mandob.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        return view('admin.mandob.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile',
            'password' => 'nullable|min:6',
            'status' => 'required|in:active,not_active',

        ]);
        $user = User::find($id);
        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->mobile = $request['mobile'];
        $user->status = $request['status'];
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        if ($request['password']) $user->password = bcrypt($request['password']);
        $user->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('mandob.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::find($id);
        $user->delete();
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}

