<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\PaymentMethod;
use Illuminate\Http\Request;

class PaymentsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = PaymentMethod::latest()->get();
        return view('admin.payments.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.payments.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'required|image',
            'status' => 'required|in:active,not_active',
            'type' => 'required|in:cash,online,wallet'

        ]);
        $payment = new PaymentMethod();
        $payment['name->ar'] = $request['name_ar'];
        $payment['name->en'] = $request['name_en'];
        $payment->status = $request['status'];
        $payment->type = $request['type'];
        if ($request->hasFile('image')) {
            $payment->setImageAttribute();
        }
        $payment->save();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('payments.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = PaymentMethod::find($id);
        return view('admin.payments.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'nullable|image',
            'status' => 'required|in:active,not_active',
            'type' => 'required|in:cash,online,wallet'
        ]);
        $payment = PaymentMethod::find($id);
        $payment['name->ar'] = $request['name_ar'];
        $payment['name->en'] = $request['name_en'];
        $payment->status = $request['status'];
        $payment->type = $request['type'];
        if ($request->hasFile('image')) {
            $payment->setImageAttribute();
        }
        $payment->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('payments.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $city = PaymentMethod::find($id);
        $city->delete();
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}
