<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Product;
use App\Models\ProductService;
use App\Models\Service;
use Illuminate\Http\Request;

class ProductsController extends Controller
{
    public function index()
    {
        $rows = Product::orderByDesc('id')->get();
        return view('admin.products.index', compact('rows'));
    }

    public function create()
    {
        $categories = Category::all();
        $services = Service::all();
        return view('admin.products.create', compact('categories', 'services'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_ar' => 'required',
            'name_en' => 'required',
            'category_id' => 'required|exists:categories,id',
            'image' => 'required|image'
        ]);

        $product = new Product();
        $product['name->ar'] = $request['name_ar'];
        $product['name->en'] = $request['name_en'];
        $product['category_id'] = $request['category_id'];
        $product['status'] = $request['status'];
        $product->setImageAttribute();
        $product->save();
        $service_count = count($request['service_id']);
        for ($i = 0; $i < $service_count; $i++) {

            ProductService::create([
                'service_id' => $request['service_id'][$i],
                'price' => $request['price'][$i],
                'product_id' => $product->id,
            ]);
        }
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('products.index');
    }

    public function edit($id)
    {
        $row = Product::find($id);
        $categories = Category::all();
        $services = Service::all();
        return view('admin.products.edit', compact('row', 'categories', 'services'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'name_ar' => 'required',
            'name_en' => 'required',
            'category_id' => 'required|exists:categories,id',

        ]);
        $product = Product::find($id);
        $product['name->ar'] = $request['name_ar'];
        $product['name->en'] = $request['name_en'];
        $product['category_id'] = $request['category_id'];
        $product['status'] = $request['status'];
        if ($request->hasFile('image')) $product->setImageAttribute();
        $product->update();

        $service_counts = count($request['service_id']);
        if (isset($request['service_id'])) {
            ProductService::where('product_id', $product->id)->delete();
            for ($i = 0; $i < $service_counts; $i++) {

                ProductService::create([
                    'service_id' => $request['service_id'][$i],
                    'price' => $request['price'][$i],
                    'product_id' => $product->id,
                ]);
            }
        }
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('products.index');
    }
    public function destroy($id){
        Product::destroy($id);
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('products.index');
    }

}
