<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Subscription;
use App\User;
use Illuminate\Http\Request;

class UsersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::where('type', 'client')->latest()->get();
        return view('admin.users.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $subscriptions = Subscription::where('status', 'active')->get();
        return view('admin.users.create', compact('subscriptions'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|unique:users,mobile',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active',
            'subscription_id' => 'nullable|exists:subscriptions,id',

        ]);
        $user = new User();
        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->subscription_id = $request['subscription_id'];
        $user->type = 'client';
        $user->status = $request['status'];
        $user->password = bcrypt($request['password']);
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        $user->save();
        $rand = rand('111', '999');
        $user->personal_code = $user->id . $rand;

        $user->wallet += $user->subscription->price ;

        $user->update();

        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('users.index');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        $subscriptions = Subscription::where('status', 'active')->get();
        return view('admin.users.edit', compact('row', 'subscriptions'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile',
            'password' => 'nullable|min:6',
            'status' => 'required|in:active,not_active',
            'subscription_id' => 'nullable|exists:subscriptions,id',

        ]);
        $user = User::find($id);
        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->mobile = $request['mobile'];
        $user->subscription_id = $request['subscription_id'];
        $user->status = $request['status'];
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        if ($request['password']) $user->password = bcrypt($request['password']);
        $user->update();
        if ($request['subscription_id'] != $user->subscription_id){
            $user->wallet += $user->subscription->price;
        }
        $user->update();
        toast('تمت العملية بنجاح', 'success', 'left');
        return redirect()->route('users.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::find($id);
        $user->delete();
        toast('تمت العملية بنجاح', 'success', 'left');
        return back();
    }
}
