<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CategoriesResource;
use App\Http\Resources\ProductsResource;
use App\Http\Resources\ServicesResource;
use App\Models\Cart;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;
use JWTAuth;

class CategoriesController extends Controller
{
    public function categories()
    {
        $rows = Category::whereStatus('active')->get();

        if (\request()->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
            }

            $product_in_cart = Cart::where('user_id', $user->id)->where('status', 'cart')->sum('count');
            $prices = Cart::where('user_id', $user->id)->where('status', 'cart')->sum('price');

        } else {
            $product_in_cart = 0;
            $prices = 0;
        }



        return CategoriesResource::collection($rows)->additional(['value' => true, 'cart_count' => $product_in_cart, 'prices' => $prices]);
    }

    public function products($id)
    {
        $rows = Product::whereCategoryId($id)->get();

        if (\request()->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
            }

            $product_in_cart = Cart::where('user_id', $user->id)->where('status', 'cart')->sum('count');
            $prices = Cart::where('user_id', $user->id)->where('status', 'cart')->sum('price');

        } else {
            $product_in_cart = 0;
            $prices = 0;
        }
        return ProductsResource::collection($rows)->additional(['value' => true, 'cart_count' => $product_in_cart, 'prices' => $prices]);
    }

    public function product_services($id,Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $product = Product::find($id);
        $rows = $product->services;
        return ServicesResource::collection($rows)->additional(['value' => true]);

    }

    public function single_product($id, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $product = Product::find($id);
        $data = new ProductsResource($product);
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function search(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'search' => 'required'
        ]);
        if ($validator->passes()) {


            $rows = Product::where('name->' . \App::getLocale(), 'LIKE', "%{$request->search}%")->get();
            return ProductsResource::collection($rows)->additional(['value' => true]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
}
