<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\OrderResource;
use App\Models\Order;
use Illuminate\Http\Request;
use JWTAuth;


class MandobController extends Controller
{
    public function orders($flag, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }


        if ($flag == 'receive_orders') {
            $orders = $user->mandob_orders()->where('status', 'accepted')->latest()->paginate(10);
        } else {
            $orders = $user->mandob_orders()->where('status', 'clothes_finish_wash')->latest()->paginate(10);
        }
        return OrderResource::collection($orders)->additional(['value' => true, 'code' => 200]);

    }

    public function accept_order($id, Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        Order::whereId($id)->update([
            'status' => 'driver_accept'
        ]);
        $order = Order::find($id);
        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data]);

    }

    public function orders_history(Request $request, $status = null)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        if ($status == 'in_progress') {
            $orders = $user->mandob_orders()->whereNotIn('status', ['waiting', 'cancel', 'in_complete', 'finish'])->latest()->paginate(10);
        } elseif ($status == 'cancel') {
            $orders = $user->mandob_orders()->where('status', 'cancel')->latest()->paginate(10);
        } elseif ($status == 'finish') {
            $orders = $user->mandob_orders()->where('status', 'finish')->latest()->paginate(10);
        } else {
            $orders = $user->mandob_orders()->latest()->paginate(10);
        }
        return OrderResource::collection($orders)->additional(['value' => true, 'code' => 200]);
    }

    public function mandob_on_way(Request $request, $order_id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        Order::whereId($order_id)->update([
            'status' => 'driver_in_way'
        ]);
        $order = Order::find($order_id);
        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function clothes_back(Request $request, $order_id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        Order::whereId($order_id)->update([
            'status' => 'finish'
        ]);
        $order = Order::find($order_id);
        
        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data]);
    }
}
