<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CartResource;
use App\Http\Resources\OrderResource;
use App\Models\Cart;
use App\Models\Coupon;
use App\Models\Notification;
use App\Models\Order;
use App\Models\OrderCart;
use App\Models\OrderMessage;
use App\Models\Setting;
use App\User;
use Carbon\Carbon;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;

class OrdersController extends Controller
{
    public function order(Request $request, $id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $order = Order::where(['id' => $id])->first();
        if (!$order) {
            return response()->json(['value' => false, 'msg' => 'لا يوجد طلب بهذا الرقم', 'code' => 422]);
        }
        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function add_order(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        Order::whereStatus('in_complete')->whereUserId($user->id)->delete();

        $carts = $user->carts->where('status', 'cart')->pluck('id');

        if ($carts->count() == 0) {
            return response()->json(['value' => false, 'msg' => 'السلة فارغه', 'code' => 422]);
        }
        $setting = Setting::first();
        if ($setting) {
            $tax = $setting->tax ? $setting->tax : 0;
            $delivery_cost = $setting->delivery_cost ? $setting->delivery_cost : 0;
            $receive_cost = $setting->receive_cost ? $setting->receive_cost : 0;
        } else {
            $tax = 0;
            $delivery_cost = 0;
            $receive_cost = 0;
        }
        $order = new Order();
        $order->user_id = $user->id;
        $order->status = 'in_complete';
        $order->delivery_cost = $delivery_cost;
        $order->tax = $tax;
        $order->receive_cost = $receive_cost;
        $carts_prices = $user->carts()->where('status', 'cart')->sum('price');
        $order->total_price = $carts_prices;
        $all_tax = ($carts_prices * $tax) / 100;
        $price = $carts_prices + $all_tax + $delivery_cost + $receive_cost;
        $order->all_total_price = $price;
        $order->rest_amount = $price;
        $order->save();
        $rand = rand('111', '999');
        $order->code = $order->id . $rand;
        $order->update();
        foreach ($carts as $cart_id) {

            $order_cart = new OrderCart();
            $order_cart->order_id = $order->id;
            $order_cart->cart_id = $cart_id;
            $order_cart->save();
        }
        $data = new OrderResource($order);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

    }

    public function coupon_discount(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'code' => 'required',
            'order_id' => 'required|exists:orders,id'

        ]);
        if ($validator->passes()) {
            $order = Order::find($request->order_id);
            $coupon = Coupon::where(['status' => 'active', 'code' => $request->code])->whereDate('start_date', '<=', Carbon::now()->toDateString())->whereDate('end_date', '>=', Carbon::now()->toDateString())->first();
            if (!$coupon || $order->coupon_id == $coupon->id) {
                return response()->json(['value' => false, 'msg' => 'الرمز خطأ', 'code' => 422]);
            }
            $discount = ($order->all_total_price * $coupon->discount_percent) / 100;
            $all_dicount = $order->all_total_price - $discount;
            $order->all_total_price = $all_dicount;
            $order->rest_amount = $all_dicount;
            $order->coupon_id = $coupon->id;
            $order->update();
            $data = new OrderResource($order);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

    public function order_cart(Request $request, $id)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $order = Order::find($id);
        if (!$order) {
            return response()->json(['value' => false, 'msg' => 'لا يوجد طلب بهذا الرقم', 'code' => 422]);
        }
        $order_carts = $order->carts()->get();

        return CartResource::collection($order_carts)->additional(['value' => true, 'code' => 200]);
    }

    public function order_confirmation(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'address_id' => 'required|exists:addresses,id',
            'payment_id' => 'required|exists:payment_methods,id',
            'notes' => 'required',
            'delivery_date' => 'required',
            'receive_time' => 'required',
            'receive_date' => 'required',
            'delivery_time' => 'required'

        ]);
        if ($validator->passes()) {

            $order = Order::find($request->order_id);
            if ($order->status == 'waiting') {
                return response()->json(['value' => false, 'msg' => 'تم استكمال الطلب بالفعل', 'code' => 422]);
            }
            $order->address_id = $request->address_id;
            $order->payment_id = $request->payment_id;
            $order->notes = $request->notes;
            $order->delivery_date = $request->delivery_date;
            $order->receive_time = $request->receive_time;
            $order->receive_date = $request->receive_date;
            $order->delivery_time = $request->delivery_time;
            $order->status = 'waiting';

            $order->save();
            foreach ($order->carts as $cart) {
                Cart::find($cart->id)->update(['status' => 'order']);
            }

            if ($order->payment->type == 'wallet') {
                $user_amount = $user->wallet - $order->all_total_price;
                if ($user_amount <= 0) {//-10
                    $order->paid_amount = $user->wallet;
                    $order->rest_amount = $user_amount * -1;
                    $order->update();
                    $user->wallet = 0;
                    $user->update();
                } else {
                    $user->wallet = $user_amount;
                    $user->update();
                    $order->paid_amount = $order->all_total_price;
                    $order->rest_amount = 0;
                    $order->update();
                }
            }

            $data = new OrderResource($order);
            return response()->json(['value' => true, 'data' => $data, 'msg' => 'تم ارسال طلبكم', 'code' => 200]);

        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

    public function cancel_order(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'cancel_message' => 'required'
        ]);
        if ($validator->passes()) {

            $order = Order::where(['id' => $request->order_id, 'user_id' => $user->id])->first();
            if (!$order) {
                return response()->json(['value' => false, 'msg' => 'لا يوجد طلب بهذا الرقم', 'code' => 422]);
            }
            $order->status = 'cancel';
            $order->cancel_note = $request->cancel_message;
            $order->update();
            $data = new OrderResource($order);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);

    }

    public function contact_mandob(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'order_id' => 'required|exists:orders,id',
            'message' => 'required'
        ]);
        if ($validator->passes()) {

            $order = Order::where(['id' => $request->order_id, 'user_id' => $user->id])->first();
            if (!$order) return response()->json(['value' => false, 'msg' => 'لا يوجد طلب بهذا الرقم', 'code' => 422]);
            if (!$order->mandob_id) return response()->json(['value' => false, 'msg' => 'لم يخصص مندوب لهذا الرقم', 'code' => 422]);
            OrderMessage::create($request->all());


            $tokens = $order->mandob->tokens()->where('status', 'connected')->get();

            $notification = new Notification();
            $notification['user_id'] = $order->mandob_id;
            $notification['body->ar'] = $request['message'];
            $notification['body->en'] = $request['message'];
            $notification['type'] = 'order';
            $notification->save();


            foreach ($tokens as $token) {
                if ($token->lang = 'ar') {
                    $title = $request['message'];
                    $body = $request['message'];
                } else {
                    $title = $request['message'];
                    $body = $request['message'];
                }
                $push = new PushNotification('fcm');

                if ($token->device_type == 'ios') {

                    $msg = [
                        'data' => [
                            'title_ar' => $request['message'],
                            'title' => $title,
                            'body' => $body,
                            'title_en' => $request['message'],
                            'body_ar' => $request['message'],
                            'body_en' => $request['message'],
                            'type' => 'order',
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $request['message'],
                            'title_en' => $request['message'],
                            'body_ar' => $request['message'],
                            'body_en' => $request['message'],
                            'type' => 'order',
                            'title' => $title,
                            'body' => $body,

                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $request['message'],
                            'title_en' => $request['message'],
                            'body_ar' => $request['message'],
                            'body_en' => $request['message'],
                            'type' => 'order',
                            'title' => $title,
                            'body' => $body,
                            'sound' => 'default',
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }

            }

            return response()->json(['value' => true, 'data' => 'تم ارسال الرسالة', 'code' => 200]);

        }

        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function status_orders(Request $request, $status = null)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        if ($status == 'waiting') {
            $orders = $user->client_orders()->where('status', 'waiting')->latest()->paginate(10);
        } elseif ($status == 'in_progress') {
            $orders = $user->client_orders()->whereNotIn('status', ['waiting', 'cancel', 'in_complete', 'finish'])->latest()->paginate(10);
        } elseif ($status == 'cancel') {
            $orders = $user->client_orders()->where('status', 'cancel')->latest()->paginate(10);
        } elseif ($status == 'finish') {
            $orders = $user->client_orders()->where('status', 'finish')->latest()->paginate(10);
        } elseif ($status == 'in_complete') {
            $orders = $user->client_orders()->where('status', 'in_complete')->latest()->paginate(10);
        } else {
            $orders = $user->client_orders()->latest()->paginate(10);
        }
        return OrderResource::collection($orders)->additional(['value' => true, 'code' => 200]);
    }
}
