<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\BanksResources;
use App\Http\Resources\SubscriptionsResource;
use App\Models\Bank;
use App\Models\BankTransfer;
use App\Models\Subscription;
use Illuminate\Http\Request;
use JWTAuth;

class PackagesController extends Controller
{
    public function packages()
    {
        $rows = Subscription::whereStatus('active')->get();
        return SubscriptionsResource::collection($rows)->additional(['value' => true]);
    }

    public function banks()
    {
        $rows = Bank::all();
        return BanksResources::collection($rows)->additional(['value' => true]);
    }

    public function subscribe_package(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'bank_id' => 'required|exists:banks,id',
            'subscription_id' => 'required|exists:subscriptions,id',
            'image' => 'required|image'
        ]);
        if ($validator->passes()) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            $request['user_id'] = $user->id;
            $request['status'] = 'waiting';
            BankTransfer::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.subscribed')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function subscription_history()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = $user->subscription_history()->get();
        return SubscriptionsResource::collection($rows)->additional(['value' => true]);

    }
}
