<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\UserResource;
use App\Models\Contact;
use App\Models\Token;
use App\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Tymon\JWTAuth\Exceptions\JWTException;
use JWTAuth;

class UsersController extends Controller
{

    public function register(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $validator = \Validator::make($request->all(), [
            'mobile' => ['required', 'unique:users,mobile'],
            'device_token' => 'required',
            'device_type' => 'required|in:ios,android',
            'password' => 'required|confirmed|min:6',
            'password_confirmation' => 'sometimes|required_with:password',
            'name' => ['required', 'unique:users,name'],
            'email' => 'required|email|unique:users,email',


        ]);
        if ($validator->passes()) {
            $user = new User();
            $user['mobile'] = $request['mobile'];
            $user['email'] = $request['email'];
            $user['name'] = $request['name'];
            $user['password'] = bcrypt($request['password']);
            $user['type'] = 'client';
            $user['status'] = 'active';


            $user->save();
            $rand = rand('111', '999');
            $user->personal_code = $user->id . $rand;
            $user->update();
            $check = Token::where('token', $request['device_token'])->first();
            if ($check) {
                $check->status = 'connected';
                $check->user_id = $user->id;
                if ($request['device_type']) {
                    $check->device_type = $request['device_type'];
                }
                $check->device_language = $lang;
                $check->update();
            } else {
                Token::create([
                    'user_id' => $user->id,
                    'token' => $request['device_token'],
                    'device_type' => $request['device_type'],
                    'status' => 'connected',
                    'device_language' => $lang
                ]);
            }

            $data = new UserResource($user);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function login(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'mobile' => 'required',
            'password' => 'required',
            'device_token' => 'required',
            'device_type' => 'required|in:ios,android',

        ]);
        if ($validator->passes()) {

            $auth = ['mobile' => $request->input('mobile'), 'password' => $request->input('password'), 'status' => 'active'];


            try {
                if (!$token = JWTAuth::attempt($auth, ['exp' => Carbon::now()->addDays(7300)->timestamp])) {

                    return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_password')], 422);
                }
            } catch (JWTException $e) {
                return response()->json(['value' => false, 'msg' => 'could_not_create_token'], 500);
            }
            $user = User::whereMobile($request['mobile'])->first();
            $check = Token::where('token', $request['device_token'])->first();
            if ($check) {
                $check->status = 'connected';
                if ($request['device_type']) {
                    $check->device_type = $request['device_type'];
                }
                $check['user_id'] = $user->id;
                $check->device_language = $lang;

                $check->update();
            } else {
                Token::create([
                    'user_id' => $user->id,
                    'token' => $request['device_token'],
                    'device_type' => $request['device_type'],
                    'status' => 'connected',
                    'device_language' => $lang,
                ]);
            }

            $data = new UserResource($user);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function logout(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $validator = \Validator::make($request->all(), [
            'device_token' => 'required|exists:device_tokens,token'
        ]);
        if ($validator->passes()) {

            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }


            $exist_token = Token::where(['token' => $request['device_token']])->first();
            if (!$exist_token) return response()->json(['value' => false, 'msg' => 'device token and auth not match', 'code' => 401]);

            $exist_token->status = 'disconnected';
            $exist_token->update();

            JWTAuth::invalidate(JWTAuth::getToken());
            return response()->json(['value' => true, 'data' => \Lang::get('data.logout'), 'code' => 200]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }


    }

    public function update_profile(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'name' => 'unique:users,name,' . $user->id,
            'email' => 'unique:users,email,' . $user->id,
            'mobile' => 'unique:users,mobile,' . $user->id,

            'image' => 'image'
        ]);
        if ($validator->passes()) {
            $user['name'] = $request['name'] ? $request['name'] : $user->name;
            $user['email'] = $request['email'] ? $request['email'] : $user->email;
            $user['mobile'] = $request['mobile'] ? $request['mobile'] : $user->mobile;
            if ($request->hasFile('image')) {
               $user->setImageAttribute();
            }
            $user->update();
            $data = new UserResource($user);
            return response()->json(['value' => true, 'data' => $data]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function forget_password(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'mobile' => 'required'
        ]);
        if ($validator->passes()) {

            $user = User::whereMobile($request['mobile'])->first();
            if (!$user) return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_mobile'), 'code' => 422]);
            $code = rand(1111, 9999);
            $user->confirm_code = $code;
            $user->update();

            // mobile code sms
            $data = new UserResource($user);
            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function check_forget_code(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'mobile' => 'required|exists:users,mobile',
            'code' => 'required|exists:users,confirm_code'
        ]);
        if ($validator->passes()) {
            $user = User::whereMobile($request['mobile'])->first();
            if (!$user) return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_mobile'), 'code' => 422]);
            if ($user->confirm_code != $request['code']) return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_code'), 'code' => 422]);
            $data = new UserResource($user);
            return response()->json(['value' => true, 'data' => $data, 'msg' => \Lang::get('data.correct_code'), 'code' => 200]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function change_password(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'mobile' => 'required|exists:users,mobile',
            'password' => 'required|min:6',
            'device_token' => 'required',
            'device_type' => 'required|in:android,ios',

        ]);
        if ($validator->passes()) {

            $user = User::whereMobile($request['mobile'])->first();
            $user->password = bcrypt($request['password']);
            $user->update();
            $check = Token::where('token', $request['device_token'])->first();
            if ($check) {
                $check->status = 'connected';
                if ($request['device_type']) {
                    $check->device_type = $request['device_type'];
                }
                $check['user_id'] = $user->id;
                $check->device_language = $lang;

                $check->update();
            } else {
                Token::create([
                    'user_id' => $user->id,
                    'token' => $request['device_token'],
                    'device_type' => $request['device_type'],
                    'status' => 'connected',
                    'device_language' => $lang
                ]);
            }
            $data = new UserResource($user);


            return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function change_old_password(Request $request)
    {

        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $validator = \Validator::make($request->all(), [
            'old_password' => 'required',
            'new_password' => 'required|confirmed',
            'new_password_confirmation' => 'required'
        ]);
        if ($validator->passes()) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            if (\Hash::check($request['old_password'], $user->password)) {
                $user->password = bcrypt($request['new_password']);
                $user->update();
                $data = new UserResource($user);
                return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
            } else {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.password_not_match'), 'code' => 422]);
            }

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }

    }

    public function contact_us(Request $request)
    {
        $lang = $request->header('Accept-Language','ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'message' => 'required',
        ]);
        if ($validator->passes()) {
            $request['user_id'] = $user->id;
            Contact::create($request->all());
            return response()->json(['value' => true, "data"=>\Lang::get('data.contact_sent')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function getAuthenticatedUser()
    {
        try {

            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['user_not_found'], 404);
            }

        } catch (Tymon\JWTAuth\Exceptions\TokenExpiredException $e) {

            return response()->json(['token_expired'], $e->getStatusCode());

        } catch (Tymon\JWTAuth\Exceptions\TokenInvalidException $e) {

            return response()->json(['token_invalid'], $e->getStatusCode());

        } catch (Tymon\JWTAuth\Exceptions\JWTException $e) {

            return response()->json(['token_absent'], $e->getStatusCode());

        }

        return response()->json(compact('user'));
    }
}
