<?php

namespace App\Http\Resources;

use App\Models\Setting;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class OrderResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $all_status = ['cancel', 'in_complete', 'waiting', 'accepted', 'driver_accept', 'driver_in_way', 'driver_take_clothes', 'washing', 'clothes_finish_wash', 'clothes_back', 'finish'];
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('wrong token'), 'code' => 401]);
        }
        $obj = new \stdClass();
        $lang = $request->header('Accept-Language', 'ar');
        return [
            'id' => $this->id,
            'user_mobile' => $user->mobile ? $user->mobile : '',
            'status' => $this->status,
            'code' => $this->code,
            'receive_date' => $this->receive_date ? $this->receive_date : '',
            'receive_time' => $this->receive_time ? $this->receive_time : '',
            'delivery_date' => $this->delivery_date ? $this->delivery_date : '',
            'delivery_time' => $this->delivery_time ? $this->delivery_time : '',
            'address' => $this->address_id ? new AddressesResource($this->address) : $obj,
            'notes' => $this->notes ? $this->notes : '',
            'cancel_note' => $this->cancel_note ? $this->cancel_note : '',
            'payment' => $this->payment_id ? new PaymentMethodsResource($this->payment) : $obj,
            'mandob_id' => $this->mandob_id ? (string)$this->mandob_id : '',
            'mandob_name' => $this->mandob_id ? $this->mandob->name : '',
            'total_price' => $this->total_price ? (integer)$this->total_price : 0,
            'discount_percent' => $this->coupon_id ? (integer)$this->coupon->discount_percent : 0,
            'tax' => $this->tax ? (integer)$this->tax : 0,
            'receive_cost' => $this->receive_cost ? (integer)$this->receive_cost : 0,
            'delivery_cost' => $this->delivery_cost ? (integer)$this->delivery_cost : 0,
            'paid_amount' => $this->paid_amount ? (integer)$this->paid_amount : 0,
            'rest_amount' => $this->rest_amount ? (integer)$this->rest_amount : 0,
            'all_total_price' => $this->all_total_price ? (integer)$this->all_total_price : 0,
            'all_status' => $all_status
        ];
    }
}
